==> haskell-special-values-0.1.0.0-202-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-special-values.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 special-values
version:              0.1.0.0
visibility:           public
id:                   special-values-0.1.0.0-GR5CnE1LOcW7neZzzrBoab
key:                  special-values-0.1.0.0-GR5CnE1LOcW7neZzzrBoab
license:              MIT
copyright:            2017 Daniel Mendler
maintainer:           Daniel Mendler <mail@daniel-mendler.de>
author:               Daniel Mendler <mail@daniel-mendler.de>
homepage:             https://github.com/minad/special-values#readme
synopsis:             Typeclass providing special values
description:
    Special values are provided by a SpecialValues typeclass. Those can be used for example by QuickCheck, see quickcheck-special.

category:             Testing
abi:                  0cf8e752144a7429fcda36c44992cc38
exposed:              True
exposed-modules:      Data.SpecialValues
hidden-modules:       Paths_special_values
import-dirs:          /usr/lib/ghc-9.2.8/site-local/special-values-0.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/special-values-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-special-values
hs-libraries:         HSspecial-values-0.1.0.0-GR5CnE1LOcW7neZzzrBoab
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    ieee754-0.8.0-jBSJf9r7fS9cohIIWFx2y
    scientific-0.3.7.0-KUJ0yQBDqbB75MLhDe7uzc text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-special-values/html/special-values.haddock

haddock-html:         /usr/share/doc/haskell-special-values/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-special-values-0.1.0.0-204-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-special-values.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 special-values
version:              0.1.0.0
visibility:           public
id:                   special-values-0.1.0.0-Cbjf1ToVOfTFQ51L6SAyPL
key:                  special-values-0.1.0.0-Cbjf1ToVOfTFQ51L6SAyPL
license:              MIT
copyright:            2017 Daniel Mendler
maintainer:           Daniel Mendler <mail@daniel-mendler.de>
author:               Daniel Mendler <mail@daniel-mendler.de>
homepage:             https://github.com/minad/special-values#readme
synopsis:             Typeclass providing special values
description:
    Special values are provided by a SpecialValues typeclass. Those can be used for example by QuickCheck, see quickcheck-special.

category:             Testing
abi:                  a5fb68d46bac65e86e9708ebf74b35b7
exposed:              True
exposed-modules:      Data.SpecialValues
hidden-modules:       Paths_special_values
import-dirs:          /usr/lib/ghc-9.2.8/site-local/special-values-0.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/special-values-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-special-values
hs-libraries:         HSspecial-values-0.1.0.0-Cbjf1ToVOfTFQ51L6SAyPL
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    ieee754-0.8.0-jBSJf9r7fS9cohIIWFx2y
    scientific-0.3.7.0-8x4tZ4xzXsRTNLFKkeuvD text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-special-values/html/special-values.haddock

haddock-html:         /usr/share/doc/haskell-special-values/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
